DNS RESTful API             
========      

# API
The API gives access to the progress information for SIPs previously submitted to the DNS. Various kinds of SIP-Identification can be used to get the appropriate information.

## Service URL
Contractors *must* use the Service URL of their associated Service Provider. Secure HTTP (https) is supported exclusively. Redirect from http to https depends on the Providers facilities.  According to RFC-2616 all characters with special function in URL have to be encoded when using one of the services.

# Services

## Service "status/index"

* Service request: [/status/index](https://server/daweb3/status/index)
* Request method: GET
* Parameters:
    * identifier: the DNS internal identifier,
    * origName: the name of the object was submitted to the DNS,
    * urn: the urn generated by DNS,
    * containerName: the name of the SIP container orgininally submitted to the DNS
* Returns: JSON

### Description

Service returns information about the actual state of a SIP delivered to the DNS System. The SIP in request must be identified by one of the above defined parameters. It can be identified either with the DNS internal *identifier*, with the filename of the SIP as it was submitted originally into the system (*origName*) or the *urn* generated by DNS (or already being sent by SIP). 

The originalName should be the name, the item is listed in your own domain, while the other identifiers (identifier and urn) are build during the ingest process (or being sent by SIP). Container name correlates with the name of the file submitted including the file extension.

In case of sending Deltas to objects (and to determine their respective states during processing), *containerName* or *urn* should be used, while the *origName* of objects is not changed anymore. 

The JSON returned includes all types of information about the SIP submitted or the AIP being stored. 

* DNS specific process status: 
    * archived if AIP was successfully processed, 
    * "package in progress error" if DNS is unable to process SIP. The DNS internal status code is added as embraced number 
* all identifiers supported and/or generated by DNS
* Contractors identification

#### Description of fields containing in the JSON-Response
The cas of success and not sucess is that the Json Request contains two blocks with the same fields. In case of not success 
* "type":"QueueEntry" : describes the error  
* "type":"Queue" 	  : contains package informations
The only difference between the two responses is the field 'package' in the sucess response.

* in case of success:
	* "type": "Object",
    * "status": String: value of the package state,
    * "statusInt": Integer: value of the package state,
    * "statusLongDescription": String: in case of success it is equal to the field 'status',
    * "urn": String: the urn of the package,
    * "contractor": String: the name of the contractor,
    * "origName": String: the original name of the package,
    * "identifier": String: the identifier of the package,
    * "packages": String-Array:  number of deltas in the package
    
    Example:
    
    {  "result": [
	    {
	      "type": "Object",
	      "status": "archived",
	      "statusInt": 100,
	      "statusLongDescription": "archived",
	      "urn": "urn:nbn:de:danrw-1-201909122271",
	      "contractor": "TEST",
	      "origName": "AirportFireService1WorringerPlatz",
	      "identifier": "1-201909122271",
	      "packages": [ 1 ]
	    }
  	]
	}
    
* in case of error:    
	* "type": "QueueEntry",
    * "urn": String: the urn of the package or null,
    * "contractor": String: the name of the contractor,
    * "origName": String: the original name of the package,
    * "identifier": String: the identifier of the package,
   	* "status": String: value of the package state,
    * "statusInt": Integer: value of the package state,
    * "statusLongDescription": String: long discription of the error,
    
    Example: 
    { "result": [
	    {
	      "type": "QueueEntry",
	      "urn": null,
	      "contractor": "TEST",
	      "origName": "MultimediaTestSip-NOK",
	      "identifier": "1-201909112245",
	      "status": "package in progress error: (114) ",
	      "statusInt": 114,
	      "statusLongDescription": [
	        "package in progress error: (114) ",
	        "Inkonsistentes Paket![(error) Payload manifest manifest-md5.txt contains invalid file(s): [data/export_mets.xml]]"
	      ]
	    },
	    {
	      "type": "Object",
	      "status": "Object is in transient state",
	      "statusInt": 50,
	      "statusLongDescription": "Object is in transient state",
	      "urn": null,
	      "contractor": "TEST",
	      "origName": "MultimediaTestSip-NOK",
	      "identifier": "1-201909112245",
	      "packages": [1 ]
	    }
  	]	
	}

### Example-Request

    curl -v -H "Accept: application/json" X GET -u username --url "https://server/daweb3/status/index?identifier=1-201909122271"

### Example Response    

{"result":[{"type":"Object","status":"archived","statusInt":100,"statusLongDescription":"archived","urn":"urn:nbn:de:danrw-1-201909122271","contractor":"TEST","origName":"AirportFireService1WorringerPlatz","identifier":"1-201909122271","qualityLevel": "4","packages":[1]}]}

## Authentification

Contractors must authenticate with BASIC AUTH. Credentials are same as contractor's.

[https://server/daweb3/](https://Server/daweb3/)

## Service "automatedRetrieval/queueForRetrievalJSON"

* Service request: [/automatedRetrieval/queueForRetrievalJSON](https://server/daweb3/automatedRetrieval/queueForRetrievalJSON)
* Request method: POST
* Parameters:
    * identifier: the DNS internal identifier,
    * origName: the name of the object was submitted to the DNS,
    * urn: the urn generated by DNS
* Returns: JSON


### Description
Service triggers the queuing of an Information Package for retrieval. The Information Package has to be stored within the DNS system previously and will be delivered to the Contractor's directory dedicated for package retrieval (e.g. outcoming). If successfully delivered Contractor can access the package via sftp, or if supported by Service Provider via daweb console.

The JSON POST Data must at least contain one of the following fields: urn, identifier, origName.

The response indicates the creation of retrieval request only. It does *neither* indicate successful delivery to the Contractor's outcoming directory *nor* the retrieval of DIP by Contractor.

### Example-Request

    curl -v -H "Accept: application/json" X POST -u username --url "https://server/daweb3/status/index?urn=urn%3Anbn%3Ade%3Ahbz%3A6%3A1-31323"

### Example Response    

The request should create a retrieval job. The response is: 

    {"success":"true"}
    
Otherwise 

    {"success":"false"}

### Service "/delete"

* Service request: [/delete]
    Possibilities to call it: 
    * https://Servername//daweb3/delete/index?identifier=IhrIdentifier 
    * https://Servername//daweb3/delete/index?urn=IhreURN
    * https://Servername//daweb3/delete/index?origName=IhrAblieferungsname
    * https://Servername//daweb3/delete/index?containerName=IhrContainername 
    
* Request method: GET
* Parameters:
    * identifier: the DNS internal identifier,
    * origName: the name of the object was submitted to the DNS,
    * urn: the urn generated by DNS
    * containerName: the name of the SIP container orgininally submitted to the DNS
* Returns: JSON


### Description
Service triggers the queuing of an Information Package for deletion. The Information Package has to be stored within the DNS system previously with errors.

The JSON GET Data must at least contain one of the following fields: urn, identifier, origName, containerName.

The response indicates the deletion of retrieval request. 

### Example-Request

    curl -v -H "Accept: application/json" X GET -u username --url "http://localhost:8080/delete/index?urn=urn:nbn:de:danrw-1-20190730807"

### Example Response    

The request should create a retrieval job. The response is: 

   {"result":[{"type":"QueueEntry","urn":null,"contractor":"TEST","origName":"AIP-AirportFireService1WorringerPlatz","identifier":"1-201908222145","status":"package state : (114)  will be deleted"}]}
    
Otherwise 

	{"result":[]}
   
    
# Version

* DNS RESTFul-API Version 1

# Revision

* No changes to previous version  
